import java.awt.Color;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Graphics;

import javax.swing.JComponent;
import javax.swing.JFrame;

/**
 *  Class that runs a sample GUI with one button
 *
 *  @author Nicholas R. Howe, modified by Sara Sheehan
 *  @version February 1, 2016
 */
public class CandyHeartApp extends JComponent {
	
    /** for serializing the class, ignore for now*/
	private static final long serialVersionUID = 1L;
	
	/** Window dimensions */
    public static final int DIM = 400;

    /** Sets up the GUI window */
    public static void createAndShowGUI() {
    	
        // Make sure we have nice window decorations.
        JFrame.setDefaultLookAndFeelDecorated(true);

        // Create and set up the window.
        JFrame frame = new JFrame("Basic GUI Application");

        // Make sure program quits when window closes (application only)
        try {
        		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        } catch (Exception e) {};

        // Add components
        createComponents(frame.getContentPane());

        // Display the window.
        frame.pack();
        frame.setVisible(true);
    }

    /**
     *  Creates and lays out all the components for the GUI
     *
     *  @param frame  The frame object where everything is to be created
     */
    public static void createComponents(Container pane) {
    		pane.setLayout(new FlowLayout());
    		CandyHeartApp window = new CandyHeartApp();
    		pane.add(window);
    }

    /**
     *  Draws the circle in the graphics window
     *
     *  @param g The graphics object to draw into
     */
    public void paintComponent(Graphics g) {
    		g.setColor(Color.WHITE);
    		g.fillRect(0,0,DIM,DIM);
    	
    		// draw first candy heart
        ColoredCandyHeart heart1 = new ColoredCandyHeart();
        heart1.draw(g,50,50);
        
        // draw second candy heart
        ColoredCandyHeart heart2 = new ColoredCandyHeart("True Love",Color.BLUE);
        heart2.draw(g,120,80);
    }

    /**
     *  The component will look bad if it is sized smaller than this
     *
     *  @returns The minimum dimension
     */
    public Dimension getMinimumSize() {
    		return new Dimension(DIM,DIM);
    }

    /**
     *  The component will look best at this size
     *
     *  @returns The preferred dimension
     */
    public Dimension getPreferredSize() {
    		return new Dimension(DIM,DIM);
    }


    /**
     *  Application program starts here.
     *  @param args  Command line arguments
     */
    public static void main(String[] args) {
        // Schedule a job for the event-dispatching thread:
        // creating and showing this application's GUI.
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
        	public void run() {
        			createAndShowGUI();
        		}
	    });
    }
}
